..
    This file is part of Invenio.
    Copyright (C) 2015, 2016 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.

Authors
=======

Invenio module that provides OAuth web authorization support.

- Alizee Pace <alizee.pace@gmail.com>
- Bruno Cuc <bruno.cuc@cern.ch>
- Eirini Psallida <eirini.psallida@cern.ch>
- Esteban J. G. Gabancho <esteban.gabancho@gmail.com>
- Georgios Papoutsakis <georgios.papoutsakis@cern.ch>
- Jan Aage Lavik <jan.age.lavik@cern.ch>
- Javier Delgado <javier.delgado.fernandez@cern.ch>
- Javier Martin Montull <javier.martin.montull@cern.ch>
- Jiri Kuncar <jiri.kuncar@cern.ch>
- Krzysztof Nowak <k.nowak@cern.ch>
- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
- Leonardo Rossi <leonardo.r@cern.ch>
- Ludmila Marian <ludmila.marian@gmail.com>
- Marco Neumann <marco@crepererum.net>
- Nicolas Harraudeau <nicolas.harraudeau@cern.ch>
- Orestis Melkonian <melkon.or@gmail.com>
- Pamfilos Fokianos <pamfilos.fokianos@cern.ch>
- Sami Hiltunen <sami.mikael.hiltunen@cern.ch>
- Tibor Simko <tibor.simko@cern.ch>
